###################################################
### chunk number 1: 
###################################################
library(clustvarsel)



###################################################
### chunk number 2: 
###################################################
library(MASS)
data(crabs)
#We create our data matrix X
X<-crabs[,4:8]
colnames(X)
#We look at the data
pairs(X)
#We create the crabscl vector
crabscl<-c(rep(1,50),rep(2,50),rep(3,50),rep(4,50))



###################################################
### chunk number 3: 
###################################################
clust1<-Mclust(X,G=1:5)
#Look at the results
clust1
#Get the classification given for the best model
cl1<-clust1$class
#Look at the error comparing this classification to the true classification
classError(cl1, crabscl)
#Compare the classifications
table(cl1, crabscl)



###################################################
### chunk number 4: 
###################################################
result<-clustvarsel(X,G=5)
#We can look at the results of each step of the algorithm
result$steps.info
#We create a matrix of selected variables S
S<-result$sel.var
colnames(S)



###################################################
### chunk number 5: 
###################################################
clust2<-Mclust(S,G=1:5)
#Look at the results
clust2
#Get the classification given for the best model
cl2<-clust2$class
#Look at the error comparing this classification to the true classification
classError(cl2, crabscl)
#Compare the classifications
table(cl2, crabscl)
#Compare the two classifications
table(cl1,cl2)



###################################################
### chunk number 6: 
###################################################
#Create 4-d data X with clustering information only in the first two variables
X<-matrix(0,400,4)
#Set mixing proportion pro
pro<-0.5
#Set the mean of the first cluster
mu1<-c(0,0)
#Set the mean of the second cluster
mu2<-c(3,3)
#Set the standard deviation of the first cluster
sigma1<-matrix(c(1,0.5,0.5,1),2,2,byrow=TRUE)
#Set the standard deviation of the second cluster
sigma2<-matrix(c(1.5,-0.7,-0.7,1.5),2,2,byrow=TRUE)
u<-runif(400)
library(MASS)
#Generate the clustering variables with the given parameters
for(i in 1:400)
{
ifelse(u[i]<pro,X[i,1:2]<-mvrnorm(1,mu1,sigma1),X[i,1:2]<-mvrnorm(1,mu2,sigma2))
}
#Generate the non-clustering variables
X[,3]<-rnorm(400,1.5,2)
X[,4]<-rnorm(400,2,1)
#Now we compare the system time for the two algorithms
system.time(result1 <- clustvarsel(X, G = 3, samp = T, sampsize = 200))
system.time(result2 <- clustvarsel(X, G = 3))
colnames(result1$sel.var)
colnames(result2$sel.var)



###################################################
### chunk number 7: 
###################################################
#Create 8-d data X with clustering information only in the last two variables
X<-matrix(0,200,8)
#Set mixing proportion pro
pro<-0.5
#Set the mean of the first cluster
mu1<-c(0,0)
#Set the mean of the first cluster
mu2<-c(3,3)
#Set the standard deviation of the first cluster
sigma1<-matrix(c(1,0.5,0.5,1),2,2,byrow=TRUE)
#Set the standard deviation of the second cluster
sigma2<-matrix(c(1.5,-0.7,-0.7,1.5),2,2,byrow=TRUE)
u<-runif(200)
library(MASS)
#Generate the clustering variables with the given parameters
for(i in 1:200)
{
ifelse(u[i]<pro,X[i,7:8]<-mvrnorm(1,mu1,sigma1),X[i,7:8]<-mvrnorm(1,mu2,sigma2))
}
#Generate the non-clustering variables
X[,1]<-rnorm(200,1.5,2)
X[,2]<-rnorm(200,2,1)
X[,3:4]<-mvrnorm(200,mu1,sigma1)
X[,5:6]<-mvrnorm(200,mu2,sigma2)
#Now we compare the system time for the two algorithms
system.time(result1 <- clustvarsel(X, G = 3, search = "headlong"))
system.time(result2 <- clustvarsel(X, G = 3))
colnames(result1$sel.var)
colnames(result2$sel.var)
system.time(result3 <- clustvarsel(X, G = 3, emModels2 = c("EEE",  "VVV"), search = "headlong"))
colnames(result3$sel.var)



###################################################
### chunk number 8: 
###################################################
#Create 8-d data X with clustering information only in the last two variables
X<-matrix(0,400,8)
#Set mixing proportion pro
pro<-0.5
#Set the mean of the first cluster
mu1<-c(0,0)
#Set the mean of the first cluster
mu2<-c(3,3)
#Set the standard deviation of the first cluster
sigma1<-matrix(c(1,0.5,0.5,1),2,2,byrow=TRUE)
#Set the standard deviation of the second cluster
sigma2<-matrix(c(1.5,-0.7,-0.7,1.5),2,2,byrow=TRUE)
u<-runif(400)
library(MASS)
#Generate the clustering variables with the given parameters
for(i in 1:400)
{
ifelse(u[i]<pro,X[i,7:8]<-mvrnorm(1,mu1,sigma1),X[i,7:8]<-mvrnorm(1,mu2, sigma2))
}
#Generate the non-clustering variables
X[,1]<-rnorm(400,1.5,2)
X[,2]<-rnorm(400,2,1)
X[,3:4]<-mvrnorm(400,mu1,sigma1)
X[,5:6]<-mvrnorm(400,mu2,sigma2)
#Now we compare the system time for the three algorithmic variations
system.time(result1 <- clustvarsel(X, G = 3, emModels2 = c("EEE",  "VVV"), search = "headlong", samp = T, sampsize = 200))
system.time(result2 <- clustvarsel(X, G = 3, search = "headlong"))
system.time(result3 <- clustvarsel(X, G = 3))
colnames(result1$sel.var)
colnames(result2$sel.var)
colnames(result3$sel.var)



